@@ -6,7 +6,7 @@
 # @Contact : xzregg@gmail.com
 # @Desc    : 
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from .query import Query
 from .statistic import Statistic
 
