@@ -7,10 +7,12 @@
 # @Desc    : 
 
 # 是否跟随 django 启动
+import os
+from framework.settings import settings
 LDAP_ACCOUNT_FOLLOW_START = False
 
 # 默认 ldap 服务器 端口
 LDAP_ACCOUNT_SERVER_PORT = 3891
-
+DBPATH = os.path.join(settings.PROJECT_ROOT, 'ldiftree.tmp')
 
 from settings import *
\ No newline at end of file
