@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # @Time: 2020-06-02 10:09:54.559700
 from django.http import HttpResponseRedirect
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from drf_yasg.utils import swagger_auto_schema
 
 from framework.filters import MyFilterBackend, MyFilterSerializer, OrderingFilter
@@ -9,7 +9,7 @@ from framework.route import Route
 from framework.serializer import BaseModelSerializer, EditParams, IdSerializer, IdsSerializer, \
     PaginationSerializer, ParamsSerializer, s
 from framework.utils import DATETIMEFORMAT
-from framework.views import action, CurdViewSet, notcheck, Request, Response, RspError
+from framework.views import action, CurdViewSet, notcheck, render_to_response, Request, Response, RspError
 from myadmin.models import User
 
 
@@ -50,22 +50,26 @@ class UserSet(CurdViewSet):
         return User.objects.all().prefetch_related(*['role']).select_related(*[])
 
     @swagger_auto_schema(query_serializer=MyFilterSerializer, responses=ListUserRspSerializer)
-    def list(self, request, *args, **kwargs):
-
-        return super(UserSet, self).list(request, *args, **kwargs)
+    def list(self, request):
+        return render_to_response("myadmin/user/list.html", super().list(request))
 
     @swagger_auto_schema(query_serializer=EditParams, responses=UserSerializer)
-    def edit(self, request, *args, **kwargs):
-        return super(UserSet, self).edit(request, *args, **kwargs)
+    def edit(self, request):
+
+        return render_to_response("myadmin/user/edit.html",super().edit(request))
 
     @swagger_auto_schema(query_serializer=IdSerializer, request_body=UserSerializer, responses=UserSerializer)
     def save(self, request, *args, **kwargs):
-        if not request.data.get('password', ''):
-            request.data.pop('password')
+        user_model: User = self.get_model_instance()
+        password = request.data.pop('password', '')
+        if password:
+            request.data['password'] = user_model.make_password(password)
+
         if not request.data.get('role', ''):
             request.data['role'] = []
             # raise RspError(_('至少选择一个角色'))
-        return super(UserSet, self).save(request, *args, **kwargs)
+        serializer, msg = self.save_instance(request, user_model)
+        return Response(serializer, msg)
 
     @swagger_auto_schema(request_body=IdsSerializer, responses=IdsSerializer)
     def delete(self, request, *args, **kwargs):
@@ -77,7 +81,7 @@ class UserSet(CurdViewSet):
     @swagger_auto_schema('post', request_body=ChangeStatusSerializer)
     @action(['post'])
     def change_status(self, request: Request, **kwargs):
-        params = self.ChangeStatusSerializer(request.data)
+        params = self.ChangeStatusSerializer(request.data).o
         if params.id:
             User.objects.filter(id__in=params.id).update(status=params.status)
         return Response()
@@ -94,9 +98,9 @@ class UserSet(CurdViewSet):
         """
         修改密码
         """
-        serializer = self.ChangePasswordSerializer(request.data)
+        serializer = self.ChangePasswordSerializer(request.data).o
         if self.is_post():
-            the_user = request.user
+            the_user: User = request.user
             old_password = serializer.old_password
             new_password1 = serializer.password
             new_password2 = serializer.password2
@@ -105,8 +109,8 @@ class UserSet(CurdViewSet):
             elif new_password1 != new_password2:
                 raise RspError(_('新密码两次不一样!'))
             else:
-                if the_user.password == old_password:
-                    the_user.password = new_password1
+                if the_user.check_password(old_password):
+                    the_user.set_password(new_password1)
                     the_user.clean_fields()
                     the_user.save(using='write')
                     from myadmin.views import logout
@@ -136,4 +140,3 @@ class UserSet(CurdViewSet):
                 return HttpResponseRedirect('/myadmin/index')
         user_list = User.objects.all()
         return Response(locals())
-
