@@ -6,4 +6,4 @@
 # @Contact : xzregg@gmail.com
 # @Desc :
 
-from django.utils.translation import ugettext_lazy as _
\ No newline at end of file
+from django.utils.translation import gettext_lazy as _
\ No newline at end of file
